@@ -9,6 +9,12 @@
 // Fixes clash between winsock2.h and windows.h
 #define WIN32_LEAN_AND_MEAN
 
+
+// see https://code.google.com/p/psutil/issues/detail?id=348
+#if WINVER < 0x0701  // Windows 7
+    #define PSAPI_VERSION 1
+#endif
+
 #include <Python.h>
 #include <windows.h>
 #include <Psapi.h>
@@ -545,7 +551,7 @@ get_process_memory_info(PyObject* self, PyObject* args)
         return PyErr_SetFromWindowsErr(0);
     }
 
-#if (_WIN32_WINNT >= 0x0501)
+#if (_WIN32_WINNT >= 0x0501)  // Windows XP with SP2
     private = cnt.PrivateUsage;
 #endif
 
@@ -608,7 +614,7 @@ get_process_memory_info_2(PyObject* self, PyObject* args)
         return NULL;
     }
 
-#if (_WIN32_WINNT >= 0x0501)
+#if (_WIN32_WINNT >= 0x0501)  // Windows XP with SP2
     private = process->PrivatePageCount;
 #else
     private = 0;
