@@ -78,7 +78,8 @@ WINDOWS = sys.platform.startswith("win32")
 OSX = sys.platform.startswith("darwin")
 BSD = sys.platform.startswith("freebsd")
 SUNOS = sys.platform.startswith("sunos")
-
+VALID_PROC_STATUSES = [getattr(psutil, x) for x in dir(psutil) \
+                       if x.startswith('STATUS_')]
 
 # ===================================================================
 # --- Utility functions
@@ -180,22 +181,23 @@ def which(program):
 if POSIX:
     def get_kernel_version():
         """Return a tuple such as (2, 6, 36)."""
-        major, minor, micro = os.uname()[2].split('.')[:3]
-        major = int(major)
-        minor = int(minor)
-        try:
-            micro = int(micro)
-        except ValueError:
-            s = ""
-            for x in micro:
-                if x.isdigit():
-                    s += x
-                else:
-                    break
-            if s:
-                micro = int(s)
+        s = ""
+        uname = os.uname()[2]
+        for c in uname:
+            if c.isdigit() or c == '.':
+                s += c
             else:
-                micro = 0
+                break
+        if not s:
+            raise ValueError("can't parse %r" % uname)
+        minor = 0
+        micro = 0
+        nums = s.split('.')
+        major = int(nums[0])
+        if len(nums) >= 2:
+            minor = int(nums[1])
+        if len(nums) >= 3:
+            micro = int(nums[2])
         return (major, minor, micro)
 
 def wait_for_pid(pid, timeout=1):
@@ -565,6 +567,46 @@ class TestSystemAPIs(unittest.TestCase):
         p.wait()
         self.assertNotIn(sproc.pid, [x.pid for x in psutil.process_iter()])
 
+    def test_wait_procs(self):
+        l = []
+        callback = lambda p: l.append(p.pid)
+
+        sproc1 = get_test_subprocess()
+        sproc2 = get_test_subprocess()
+        sproc3 = get_test_subprocess()
+        procs = [psutil.Process(x.pid) for x in (sproc1, sproc2, sproc3)]
+        t = time.time()
+        gone, alive = psutil.wait_procs(procs, 0.01, callback=callback)
+
+        self.assertLess(time.time() - t, 0.5)
+        self.assertEqual(gone, [])
+        self.assertEqual(len(alive), 3)
+        self.assertEqual(l, [])
+        for p in alive:
+            self.assertFalse(hasattr(p, 'retcode'))
+
+        sproc3.terminate()
+        gone, alive = psutil.wait_procs(procs, 0.03, callback=callback)
+        self.assertEqual(len(gone), 1)
+        self.assertEqual(len(alive), 2)
+        self.assertIn(sproc3.pid, [x.pid for x in gone])
+        if POSIX:
+            self.assertEqual(gone.pop().retcode, signal.SIGTERM)
+        else:
+            self.assertEqual(gone.pop().retcode, 1)
+        self.assertEqual(l, [sproc3.pid])
+        for p in alive:
+            self.assertFalse(hasattr(p, 'retcode'))
+
+        sproc1.terminate()
+        sproc2.terminate()
+        gone, alive = psutil.wait_procs(procs, 0.03, callback=callback)
+        self.assertEqual(len(gone), 3)
+        self.assertEqual(len(alive), 0)
+        self.assertEqual(set(l), set([sproc1.pid, sproc2.pid, sproc3.pid]))
+        for p in gone:
+            self.assertTrue(hasattr(p, 'retcode'))
+
     def test_TOTAL_PHYMEM(self):
         x = psutil.TOTAL_PHYMEM
         self.assertIsInstance(x, (int, long))
@@ -661,7 +703,11 @@ class TestSystemAPIs(unittest.TestCase):
         mem = psutil.swap_memory()
         assert mem.total >= 0, mem
         assert mem.used >= 0, mem
-        assert mem.free > 0, mem
+        if mem.total > 0:
+            # likely a system with no swap partition
+            assert mem.free > 0, mem
+        else:
+            assert mem.free == 0, mem
         assert 0 <= mem.percent <= 100, mem
         assert mem.sin >= 0, mem
         assert mem.sout >= 0, mem
@@ -990,6 +1036,9 @@ class TestProcess(unittest.TestCase):
     def tearDown(self):
         reap_children()
 
+    def test_no_pid(self):
+        self.assertEqual(psutil.Process().pid, os.getpid())
+
     def test_kill(self):
         sproc = get_test_subprocess(wait=True)
         test_pid = sproc.pid
@@ -1255,8 +1304,7 @@ class TestProcess(unittest.TestCase):
             self.assertRaises(ValueError, p.set_ionice, 3)
             self.assertRaises(TypeError, p.set_ionice, 2, 1)
 
-    @unittest.skipUnless(LINUX, "only available on Linux")
-    @unittest.skipUnless(get_kernel_version() >= (2, 6, 36),
+    @unittest.skipUnless(hasattr(psutil.Process, 'get_rlimit'),
         "only available on Linux >= 2.6.36")
     def test_get_rlimit(self):
         import resource
@@ -1273,8 +1321,7 @@ class TestProcess(unittest.TestCase):
                 self.assertGreaterEqual(ret[0], -1)
                 self.assertGreaterEqual(ret[1], -1)
 
-    @unittest.skipUnless(LINUX, "only available on Linux")
-    @unittest.skipUnless(get_kernel_version() >= (2, 6, 36),
+    @unittest.skipUnless(hasattr(psutil.Process, 'set_rlimit'),
         "only available on Linux >= 2.6.36")
     def test_set_rlimit(self):
         sproc = get_test_subprocess()
@@ -1863,7 +1910,6 @@ class TestProcess(unittest.TestCase):
 
     def test_invalid_pid(self):
         self.assertRaises(TypeError, psutil.Process, "1")
-        self.assertRaises(TypeError, psutil.Process, None)
         self.assertRaises(ValueError, psutil.Process, -1)
 
     def test_as_dict(self):
@@ -2209,6 +2255,7 @@ class TestFetchAllProcesses(unittest.TestCase):
     def status(self, ret):
         self.assertTrue(ret != "")
         self.assertTrue(ret != '?')
+        self.assertIn(ret, VALID_PROC_STATUSES)
 
     def get_io_counters(self, ret):
         for field in ret:
